@@ -13,10 +13,17 @@ from django.utils.translation import gettext_lazy as _
 from django.views import View
 from django.views.generic.base import ContextMixin
 
+from wagtail import VERSION as WAGTAIL_VERSION
 from wagtail.admin.forms.search import SearchForm
 from wagtail.admin.modal_workflow import render_modal_workflow
 from wagtail.admin.viewsets.base import ViewSet
-from wagtail.core.permission_policies import ModelPermissionPolicy
+
+try:
+    from wagtail.permission_policies import ModelPermissionPolicy
+except ImportError:
+    # Wagtail<3.0
+    from wagtail.core.permission_policies import ModelPermissionPolicy
+
 from wagtail.search.backends import get_search_backend
 from wagtail.search.index import class_is_indexed
 
@@ -31,7 +38,7 @@ class ModalPageFurnitureMixin(ContextMixin):
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
         context.update({
-            'icon': self.icon,
+            'header_icon': self.icon,
             'page_title': self.page_title,
         })
         return context
@@ -465,7 +472,10 @@ class BaseChooseView(ModalPageFurnitureMixin, ContextMixin, View):
     icon = 'snippet'
     page_title = _("Choose")
 
-    template = 'generic_chooser/tabbed_modal.html'
+    if WAGTAIL_VERSION >= (3, 0):
+        template = 'generic_chooser/tabbed_modal_v3.html'
+    else:
+        template = 'generic_chooser/tabbed_modal.html'
 
     def get_template(self):
         return self.template
